@@ -9,9 +9,7 @@ def update_bind_status(database, bind_address, bind_status):
 
     LOG.debug("Update {} bind {} with status {}".format(database, bind_address, bind_status))
 
-    if bind_status == CREATING:
-        bind_status = CREATED
-    else:
+    if bind_status not in [CREATING, CREATED]:
         bind_status = ERROR
 
     bind = DatabaseBind.objects.get(database= database, bind_address= bind_address)
