@@ -34,7 +34,7 @@ class ServiceBind(APIView):
             return log_and_response(msg=msg, http_status=status.HTTP_204_NO_CONTENT)
 
         LOG.debug("Responding...")
-        return Response({'binds':binds}, status.HTTP_202)
+        return Response({'binds':binds}, status.HTTP_202_ACCEPTED)
 
 
     def post(self, request, database_id, format=None):
